@@ -24,7 +24,6 @@ __all__ = (
     "ArtifactPackagingType",
     "ArtifactsTypeType",
     "AuthTypeType",
-    "BucketOwnerAccessType",
     "BuildBatchPhaseTypeType",
     "BuildPhaseTypeType",
     "CacheModeType",
@@ -75,7 +74,6 @@ ArtifactNamespaceType = Literal["BUILD_ID", "NONE"]
 ArtifactPackagingType = Literal["NONE", "ZIP"]
 ArtifactsTypeType = Literal["CODEPIPELINE", "NO_ARTIFACTS", "S3"]
 AuthTypeType = Literal["BASIC_AUTH", "OAUTH", "PERSONAL_ACCESS_TOKEN"]
-BucketOwnerAccessType = Literal["FULL", "NONE", "READ_ONLY"]
 BuildBatchPhaseTypeType = Literal[
     "COMBINE_ARTIFACTS",
     "DOWNLOAD_BATCHSPEC",
